# SReview - Movie Review Sentiment Analysis with ALBERT

A simple sentiment analysis model based on the ALBERT architecture to classify Movie Review positive or negetive, hosted on Hugging Face.

## Installation

You can install the package using pip:

```bash
pip install sreview
